﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace CustomControlDemo
{
    [TemplatePart(Name = "Background", Type = typeof(Rectangle))]
    public class CustomBorder : ContentControl
    {


        public double Radius
        {
            get { return (double) GetValue(RadiusProperty); }
            set { SetValue(RadiusProperty, value); }
        }

        // Using a DependencyProperty as the backing store for Radius.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty RadiusProperty =
            DependencyProperty.Register("Radius", typeof(double), typeof(CustomBorder),
                null);


        public int Horridity
        {
            get { return (int) GetValue(HorridityProperty); }
            set { SetValue(HorridityProperty, value); }
        }

        public static readonly DependencyProperty HorridityProperty =
            DependencyProperty.Register("Horridity",
                typeof(int), typeof(CustomBorder), OnHorridityChanged);


        static void OnHorridityChanged(object sender, DependencyPropertyChangedEventArgs e)
        {
            CustomBorder target = (CustomBorder) sender;
            target.ApplyHorridity();
        }


        Rectangle background;
        protected override void OnApplyTemplate()
        {
            base.OnApplyTemplate();

            background = this.GetTemplateChild("Background") as Rectangle;

            ApplyHorridity();
        }

        private void ApplyHorridity()
        {
            if (background != null)
            {
                Color c;
                switch (this.Horridity)
                {
                    default:
                        c = Colors.White;
                        break;
                    case 1:
                        c = Colors.Gray;
                        break;
                    case 2:
                        c = Colors.Green;
                        break;
                    case 3:
                        c = Colors.Magenta;
                        break;
                }

                background.Fill = new SolidColorBrush(c);
            }
        }

    }
}
