﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace ZoomOnHover
{
    public class HoverZoomHelper
    {
        public static void AttachZoom(FrameworkElement target)
        {
            target.RenderTransform = new ScaleTransform();
            target.RenderTransformOrigin = new Point(0.5, 0.5);

            target.MouseEnter += delegate
            {

                DoubleAnimation xScaleAnimOut = MakeAnim(target, "X", 1.2);
                DoubleAnimation yScaleAnimOut = MakeAnim(target, "Y", 1.2);

                Storyboard sbOut = new Storyboard();
                sbOut.Children.Add(xScaleAnimOut);
                sbOut.Children.Add(yScaleAnimOut);

                target.Resources.Add(sbOut);


                sbOut.Completed += delegate { target.Resources.Remove(sbOut); };
                sbOut.Begin();
            };

            target.MouseLeave += delegate
            {
                DoubleAnimation xScaleAnimIn = MakeAnim(target, "X", 1);
                DoubleAnimation yScaleAnimIn = MakeAnim(target, "Y", 1);
                Storyboard sbIn = new Storyboard();
                sbIn.Children.Add(xScaleAnimIn);
                sbIn.Children.Add(yScaleAnimIn);

                target.Resources.Add(sbIn);

                sbIn.Completed += delegate { target.Resources.Remove(sbIn); };

                sbIn.Begin();
            };

        }

        private static DoubleAnimation MakeAnim(FrameworkElement target,
            string dimension, double scale)
        {
            DoubleAnimation scaleAnim;
            scaleAnim = new DoubleAnimation();
            Storyboard.SetTargetProperty(scaleAnim,
                "(FrameworkElement.RenderTransform).(ScaleTransform.Scale" + dimension + ")");
            Storyboard.SetTarget(scaleAnim, target);
            scaleAnim.Duration = new Duration(TimeSpan.FromSeconds(0.25));
            scaleAnim.To = scale;
            return scaleAnim;
        }
    }
}
